@@ -1,6 +1,6 @@
 ## Domain Registry Interface, local global cache
 ##
-## Copyright (c) 2005,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,24 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Cache;
 
 use strict;
-use warnings;
-
-use base qw(Class::Accessor::Chained::Fast);
-__PACKAGE__->mk_accessors(qw/ttl/);
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Cache - Local cache for Net::DRI
+Net::DRI::Cache
 
 =head1 DESCRIPTION
 
@@ -51,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,10 +64,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+###############################################################################################################
 sub new
 {
- my ($c,$ttl)=@_;
+ my $h=shift;
+ my $c=ref($h) || $h;
+
+ my ($ttl)=@_;
 
  my $self={
            ttl  => $ttl, ## if negative, never use cache
@@ -82,6 +86,9 @@ sub set
  my ($self,$regname,$type,$key,$data,$ttl)=@_;
  Net::DRI::Exception::err_insufficient_parameters() unless Net::DRI::Util::all_valid($regname,$type,$key);
 
+ $type=lc($type);
+ $key=lc($key); ## ok in all cases ?
+
  my $now=Net::DRI::Util::microtime();
  $ttl=$self->{ttl} unless defined($ttl);
  my $until=($ttl==0)? 0 : $now+1000000*$ttl;
@@ -90,7 +97,7 @@ sub set
         _until => $until,
        );
 
- if ($data && (ref $data eq 'HASH'))
+ if ($data && (ref($data) eq 'HASH'))
  {
   while(my ($k,$v)=each(%$data))
   {
@@ -100,7 +107,7 @@ sub set
 
  if ($self->{ttl} >= 0) ## we really store something
  {
-  $self->{data}->{$type}={} unless exists $self->{data}->{$type};
+  $self->{data}->{$type}={} unless exists($self->{data}->{$type});
  ## We store only the last version of a given key, so start from scratch
   $self->{data}->{$type}->{$key}=\%c;
  }
@@ -108,67 +115,51 @@ sub set
  return \%c;
 }
 
-sub set_result_from_cache
-{
- my ($self,$type,$key)=@_;
- Net::DRI::Exception::err_insufficient_parameters() unless Net::DRI::Util::all_valid($type,$key);
- return unless exists $self->{data}->{$type};
- $self->{data}->{$type}->{$key}->{result_from_cache}=1;
- return;
-}
-
 sub get
 {
  my ($self,$type,$key,$data,$from)=@_;
 
- return if ($self->{ttl} < 0);
+ return undef unless ($self->{ttl} >= 0);
  Net::DRI::Exception::err_insufficient_parameters() unless Net::DRI::Util::all_valid($type,$key);
- ($type,$key)=Net::DRI::Util::normalize_name($type,$key);
- return unless exists $self->{data}->{$type};
- return unless exists $self->{data}->{$type}->{$key};
+
+ $type=lc($type);
+ $key=lc($key);
+
+ return undef unless exists($self->{data}->{$type});
+ return undef unless exists($self->{data}->{$type}->{$key});
 
  my $c=$self->{data}->{$type}->{$key};
 
  if ($c->{_until} > 0 && (Net::DRI::Util::microtime() > $c->{_until}))
  {
-  delete $self->{data}->{$type}->{$key};
-  return;
- }
+  delete($self->{data}->{$type}->{$key});
+  return undef;
+ } 
 
- return if (defined $from && ($c->{_from} ne $from));
+ return undef if (defined($from) && ($c->{_from} ne $from));
 
- if (defined $data)
+ if (defined($data))
  {
-  return $c->{$data} if exists $c->{$data};
+  return (exists($c->{$data}))? $c->{$data} : undef;
  } else
  {
   return $c;
  }
-
- return;
 }
 
 sub delete_expired
 {
  my $self=shift;
  my $now=Net::DRI::Util::microtime();
- my $c=$self->{data};
+ my $c=$self->{c};
  while(my ($type,$c1)=each(%$c))
  {
   while(my ($key,$c2)=each(%{$c1}))
   {
-   delete $c->{$type}->{$key} if ($c2->{_until} > 0 && ($now > $c2->{_until}));
+   delete($c->{$type}->{$key}) if ($c2->{_until} > 0 && ($now > $c2->{_until}));
   }
  }
- return;
 }
 
-sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
-{
- my $self=shift;
- $self->{data}={};
- return;
-}
-
-####################################################################################################
+##############################################################################
 1;
