@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handle bundle of changes
 ##
-## Copyright (c) 2005,2008,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,18 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Data::Changes;
 
 use strict;
-use warnings;
+
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Data::Changes - Bundle of changes in Net::DRI
+Net::DRI::Data::Changes
 
 =head1 DESCRIPTION
 
@@ -45,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -57,11 +61,13 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 ##############################################################################################################################
 
 sub new
 {
- my ($class,$type,$op,$el)=@_;
+ my ($proto,$type,$op,$el)=@_;
+ my $class=ref($proto) || $proto;
 
  my $self={}; ## { 'type' => [ toadd, todel, toset ] }   type=host,ip,status,contact,etc...
  bless($self,$class);
@@ -84,11 +90,7 @@ sub new_set { return shift->new(shift,'set',shift); }
 sub types
 {
  my ($self,$type)=@_;
- if (! defined $type)
- {
-  my @r=sort { $a cmp $b } keys %$self;
-  return @r;
- }
+ return sort(keys(%$self)) unless defined($type);
  my @r;
  return @r unless (exists($self->{$type}) && defined($self->{$type}));
  push @r,'add' if (defined($self->{$type}->[0]));
@@ -102,13 +104,11 @@ sub _el
  my ($self,$pos,$type,$new)=@_;
  unless (defined($new))
  {
-  return unless (exists($self->{$type}) && defined($self->{$type}));
+  return undef unless (exists($self->{$type}) && defined($self->{$type}));
   return $self->{$type}->[$pos];
  }
  $self->{$type}=[] unless (exists($self->{$type}));
  $self->{$type}->[$pos]=$new;
-
- return $self;
 }
 
 sub add { return shift->_el(0,shift,shift); }
@@ -122,12 +122,5 @@ sub all_defined
  return (grep { defined } @{$self->{$type}});
 }
 
-sub is_empty
-{
- my $self=shift;
- my @o=map { $self->all_defined($_) } $self->types();
- return @o? 0 : 1;
-}
-
 ##############################################################################################################################
 1;
