@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Encapsulating raw data
 ##
-## Copyright (c) 2005-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,24 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Data::Raw;
 
 use strict;
-use warnings;
 
-use Data::Dumper ();
-use Net::DRI::Exception;
-
-use base qw(Class::Accessor::Fast);
-__PACKAGE__->mk_ro_accessors(qw(type data hint));
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Data::Raw - Encapsulating raw data for Net::DRI
+Net::DRI::Data::Raw
 
 =head1 DESCRIPTION
 
@@ -51,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -63,22 +61,23 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+
+######################################################################
 
 sub new
 {
- my ($class,$type,$data,$hint)=@_;
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+ my ($type,$data)=@_;
 
 ## type=1, data=ref to array
 ## type=2, data=string
 ## type=3, data=ref to string NOTIMPL
 ## type=4, data=path to local file NOTIMPL
-## type=5, data=object with a as_string method
-## type=6, data=complex object in a ref array
+## type=5, data=object with a as_string method NOTIMPL
 
  my $self={type => $type,
            data => $data,
-           hint => $hint || '',
           };
 
  bless($self,$class);
@@ -86,18 +85,21 @@ sub new
 }
 
 
-sub new_from_array
+sub new_from_array  
 {
- my ($class,@args)=@_;
- my @a=map { my $f=$_; $f=~s/[\r\n\s]+$//; $f; } (ref $args[0] ? @{$args[0]} : @args);
+ my $class=shift;
+ my @a=map { s/\r?\n$//; $_; } (ref($_[0]))? @{$_[0]} : @_;
  return $class->new(1,\@a);
 }
 
-sub new_from_string    { return shift->new(2,@_); } ## no critic (Subroutines::RequireArgUnpacking)
-sub new_from_xmlstring { return shift->new(2,$_[0],'xml'); } ## no critic (Subroutines::RequireArgUnpacking)
-sub new_from_object    { return shift->new(5,@_); } ## no critic (Subroutines::RequireArgUnpacking)
+sub new_from_string { return shift->new(2,shift); }
 
-####################################################################################################
+##########################################################################
+
+sub type { return shift->{type}; }
+sub data { return shift->{data}; }
+
+##########################################################################
 
 sub as_string
 {
@@ -113,15 +115,6 @@ sub as_string
   $data=~s/\r\n/\n/g;
   return $data;
  }
- if ($self->type()==5)
- {
-  Net::DRI::Exception::method_not_implemented('as_string',ref $data) unless $data->can('as_string');
-  return $data->as_string();
- }
- if ($self->type()==6)
- {
-  return Data::Dumper->new($data)->Indent(2)->Varname('')->Quotekeys(0)->Sortkeys(1)->Dump();
- }
 }
 
 sub last_line
@@ -131,7 +124,7 @@ sub last_line
  if ($self->type()==1)
  {
   my $data=$self->data();
-  return $data->[-1]; ## see above
+  return $data->[$#$data]; ## see above
  }
  if ($self->type()==2)
  {
@@ -155,5 +148,5 @@ sub as_array
  }
 }
 
-####################################################################################################
+##########################################################################
 1;
