@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol messages (pure virtual superclass)
 ##
-## Copyright (c) 2005,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::Message;
 
 use strict;
-use warnings;
 
-use base qw/Net::DRI::BaseClass/;
+use Net::DRI::Exception;
 
-__PACKAGE__->make_exception_if_not_implemented(qw/new is_success result_status parse version as_string/);
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::Message - Superclass of all protocol messages in Net::DRI
+Net::DRI::Protocol::Message
 
 =head1 DESCRIPTION
 
@@ -49,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,6 +63,12 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
+
+sub new           { Net::DRI::Exception::err_method_not_implemented(); }
+sub is_success    { Net::DRI::Exception::err_method_not_implemented(); }
+sub result_status { Net::DRI::Exception::err_method_not_implemented(); }
+sub parse         { Net::DRI::Exception::err_method_not_implemented(); }
+sub as_string     { Net::DRI::Exception::err_method_not_implemented(); }
+sub version       { Net::DRI::Exception::err_method_not_implemented(); }
 
 1;
