@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Protocol
 ##
-## Copyright (c) 2005,2008-2010,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,12 +10,14 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::RRP;
 
 use strict;
-use warnings;
 
 use base qw(Net::DRI::Protocol);
 
@@ -29,11 +31,13 @@ use DateTime;
 use DateTime::TimeZone;
 use DateTime::Format::Strptime;
 
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::RRP - RRP 1.1/2.0 Protocol for Net::DRI
+Net::DRI::Protocol::RRP
 
 =head1 DESCRIPTION
 
@@ -57,7 +61,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008-2010,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,50 +89,54 @@ our %IDS=('registrar'  => 'clID',
 
 sub new
 {
- my ($c,$ctx,$rp)=@_;
- my $drd=$ctx->{registry}->driver();
- my $self=$c->SUPER::new($ctx);
+ my $h=shift;
+ my $c=ref($h) || $h;
+
+ my ($drd,$version,$extrah)=@_;
+
+ my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
  $self->name('RRP');
- my $version=Net::DRI::Util::check_equal($rp->{version},['1.1','2.0'],'2.0'); ## 1.1 (RFC #2832) or 2.0 (RFC #3632)
+ $version=Net::DRI::Util::check_equal($version,["1.1","2.0"],"1.1"); ## 1.1 (RFC #2832) or 2.0 (RFC #3632)
  $self->version($version);
- $self->capabilities('host_update','ip',['add','del']);
- $self->capabilities('host_update','name',['set']);
- $self->capabilities('domain_update','ns',['add','del']);
- $self->capabilities('domain_update','status',['add','del']);
- $self->factories('message',sub { my $m=Net::DRI::Protocol::RRP::Message->new(@_); $m->version($version); return $m; });
- $self->factories('status',sub { return Net::DRI::Protocol::RRP::Core::Status->new(); });
+
+ $self->capabilities({ 'host_update'   => { 'ip' => ['add','del'], 'name' => ['set'] },
+                       'domain_update' => { 'ns' => ['add','del'], 'status' => ['add','del'] },
+                     });
+
+ $self->factories({ 'message' => 'Net::DRI::Protocol::RRP::Message',
+                    'status'  => 'Net::DRI::Protocol::RRP::Core::Status',
+                  });
 
  ## Verify that we have the timezone of the registry, since dates in RRP are local to registries
  my $tzname=$drd->info('tz');
  Net::DRI::Exception::usererr_insufficient_parameters('no registry timezone') unless (defined($tzname));
  my $tz;
  eval { $tz=DateTime::TimeZone->new(name => $tzname); };
- Net::DRI::Exception::usererr_invalid_parameters("invalid registry timezone ($tzname), unable to instantiate") unless (defined $tz && ref $tz);
+ Net::DRI::Exception::usererr_invalid_parameters("invalid registry timezone ($tzname)") unless (defined($tz) && ref($tz));
  my $dtp;
  eval { $dtp=DateTime::Format::Strptime->new(time_zone=>$tz, pattern=>'%Y-%m-%d %H:%M:%S.0'); };
- Net::DRI::Exception::usererr_invalid_parameters("invalid registry timezone ($tzname), unable to create parser") unless (defined $dtp && ref $dtp);
+ Net::DRI::Exception::usererr_invalid_parameters("invalid registry timezone ($tzname)") unless (defined($dtp) && ref($dtp));
  $self->{dt_parse}=$dtp;
+ 
+ bless($self,$c); ## rebless
 
- $self->_load($rp);
+ $self->_load($extrah);
  return $self;
 }
 
-my $BASE = 'Net::DRI::Protocol::RRP::Core::';
-
+## Ex:
+## 'domain' => { 'create' => [[method1,parse1],[method2,parse2],[method3,parse3]] }
 sub _load
 {
- my ($self,$rp)=@_;
- my $extramods=$rp->{extensions};
- my @class=map { $BASE.$_ } qw/Session Domain Host/;
- push @class,map { my $f=$_; if ($f=~m/^([^+])(.+)$/) { $f = $1 eq '-' ? '-'.$BASE.$2 : $BASE.$1.$2; } $f; } (ref $extramods ? @$extramods : ($extramods)) if defined $extramods && $extramods;
+ my ($self,$extrah)=@_;
 
- return $self->SUPER::_load(@class);
-}
+ my @class=map { "Net::DRI::Protocol::RRP::Core::".$_ } ('Session','Domain','Host');
+ if (defined($extrah) && $extrah)
+ {
+  push @class,map { /::/? $_ : "Net::DRI::Protocol::RRP::Extensions::".$_ } (ref($extrah)? @$extrah : ($extrah));
+ }
 
-sub transport_default
-{
- my ($self)=@_;
- return (protocol_connection => 'Net::DRI::Protocol::RRP::Connection', protocol_version => 1);
+ $self->SUPER::_load(@class);
 }
 
 ###############################################################################################
