@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Domain commands
 ##
-## Copyright (c) 2005,2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,23 +10,27 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::RRP::Core::Domain;
 
 use strict;
-use warnings;
 
 use Net::DRI::Data::Hosts;
 use Net::DRI::Protocol::RRP::Core::Status;
 use Net::DRI::Protocol::RRP;
 use Net::DRI::Util;
 
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::RRP::Core::Domain - RRP Domain commands for Net::DRI
+Net::DRI::Protocol::RRP::Core::Domain
 
 =head1 DESCRIPTION
 
@@ -50,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -72,10 +76,10 @@ sub register_commands
            check  => [ \&check, \&check_parse ],
            info   => [ \&status, \&status_parse ],
            delete => [ \&del ],
-	   renew  => [ \&renew, \&renew_parse ],
+	   renew  => [ \&renew, \&add_parse ],
 	   update => [ \&mod ],
-	   transfer_request => [ \&transfer_request ],
-	   transfer_answer  => [ \&transfer_answer ],
+	   transfer_start  => [ \&transfer_request ],
+	   transfer_answer => [ \&transfer_answer ],
          );
 
  $tmp{transfer_cancel}=[ \&transfer_answer ] if ($version eq "2.0");
@@ -88,9 +92,8 @@ sub build_msg
  Net::DRI::Exception->die(1,'protocol/RRP',2,"Domain name needed") unless defined($domain) && $domain;
  Net::DRI::Exception->die(1,'protocol/RRP',10,"Invalid domain name") unless ($domain=~m/^[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?$/i); ## from RRP grammar
  $msg->command($command) if defined($command);
- $msg->entities('EntityName','Domain');
- $msg->entities('DomainName',uc $domain);
- return;
+ $msg->entityname('Domain');
+ $msg->entities('DomainName',uc($domain));
 }
 
 sub add
@@ -100,18 +103,17 @@ sub add
  build_msg($mes,'add',$domain);
 
  ## (MAY)
- if (Net::DRI::Util::has_duration($rd))
+ if (exists($rd->{duration}) && defined($rd->{duration}) && (ref($rd->{duration}) eq 'DateTime::Duration'))
  {
   my $period=$rd->{duration}->years();
-  Net::DRI::Exceptions::usererr_invalid_parameters('period must be an integer') unless Net::DRI::Util::isint($period);
+  Net::DRI::Exceptions::usererr_invalid_parameters("period must be an integer") unless Net::DRI::Util::isint($period);
   $mes->options('Period',$period);
  }
  ## (MAY) 1 to 13 nameservers
- if (Net::DRI::Util::has_ns($rd))
+ if (exists($rd->{ns}) && defined($rd->{ns}) && (ref($rd->{ns}) eq 'Net::DRI::Data::Hosts')) 
  {
   foreach ($rd->{ns}->get_names(13)) { $mes->entities('NameServer',$_); }
  }
- return;
 }
 
 sub add_parse
@@ -124,17 +126,6 @@ sub add_parse
  my $d='registration expiration date';
  $rinfo->{domain}->{$oname}->{$Net::DRI::Protocol::RRP::DATES{$d}}=$po->{dt_parse}->parse_datetime($mes->entities($d));
  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Protocol::RRP::Core::Status->new($mes);
- $rinfo->{domain}->{$oname}->{exist}=1;
- $rinfo->{domain}->{$oname}->{action}='create';
- return;
-}
-
-sub renew_parse
-{
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
- add_parse($po,$otype,$oaction,$oname,$rinfo);
- $rinfo->{domain}->{$oname}->{action}='renew' if (exists($rinfo->{domain}->{$oname}->{action}));
- return;
 }
 
 sub _basic_command
@@ -142,13 +133,12 @@ sub _basic_command
  my ($command,$rrp,$domain)=@_;
  my $mes=$rrp->message();
  build_msg($mes,$command,$domain);
- return;
 }
 
-sub check            { my (@args)=@_; return _basic_command('check',@args);    }
-sub status           { my (@args)=@_; return _basic_command('status',@args);   }
-sub del              { my (@args)=@_; return _basic_command('del',@args);      }
-sub transfer_request { my (@args)=@_; return _basic_command('transfer',@args); }
+sub check            { return _basic_command('check',@_);   }
+sub status           { return _basic_command('status',@_);  }
+sub del              { return _basic_command('del',@_);     }
+sub transfer_request { return _basic_command('transfer',@_);}
 
 sub check_parse
 {
@@ -163,8 +153,6 @@ sub check_parse
  {
   $rinfo->{domain}->{$oname}->{exist}=0;
  }
- $rinfo->{domain}->{$oname}->{action}='check';
- return;
 }
 
 sub status_parse
@@ -174,7 +162,6 @@ sub status_parse
  return unless $mes->is_success();
 
  $rinfo->{domain}->{$oname}->{exist}=1;
- $rinfo->{domain}->{$oname}->{action}='info';
 
  while(my ($k,$v)=each(%Net::DRI::Protocol::RRP::DATES))
  {
@@ -193,18 +180,16 @@ sub status_parse
  $rinfo->{domain}->{$oname}->{status}=Net::DRI::Protocol::RRP::Core::Status->new($mes);
 
  my @ns=$mes->entities('nameserver');
- $rinfo->{domain}->{$oname}->{ns}=Net::DRI::Data::Hosts->new_set(@ns);
- return;
+ $rinfo->{domain}->{$oname}->{ns}=Net::DRI::Data::Hosts->new_set(@ns) if @ns;
 }
 
 sub transfer_answer
 {
- my ($rrp,$domain,$rd)=@_;
+ my ($rrp,$domain,$approve)=@_;
  my $mes=$rrp->message();
  build_msg($mes,'transfer',$domain);
 
- $mes->entities('Approve',(defined($rd) && ref($rd) && exists($rd->{approve}) && $rd->{approve})? 'Yes' : 'No');
- return;
+ $mes->entities('Approve',(defined($approve) && $approve)? 'Yes' : 'No');
 }
 
 sub mod
@@ -213,7 +198,7 @@ sub mod
  my $mes=$rrp->message();
  build_msg($mes,'mod',$domain);
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && ref($todo) && $todo->isa('Net::DRI::Data::Changes'));
  if ((grep { ! /^(?:ns|status)$/ } $todo->types()) ||
      (grep { ! /^(?:add|del)$/ } $todo->types('ns')) ||
      (grep { ! /^(?:add|del)$/ } $todo->types('status'))
@@ -229,24 +214,17 @@ sub mod
  
  ## $nsadd/$nsdel are Net::DRI::Data::Hosts objects
  ## Up to 13 nameservers only
- if (defined($nsadd) && !$nsadd->is_empty()) { foreach ($nsadd->get_names(13)) { $mes->entities('NameServer',$_) } }
- if (defined($nsdel) && !$nsdel->is_empty()) { foreach ($nsdel->get_names(13)) { $mes->entities('NameServer',$_.'=') } }
+ if (defined($nsadd)) { foreach ($nsadd->get_names(13)) { $mes->entities('NameServer',$_) } }
+ if (defined($nsdel)) { foreach ($nsdel->get_names(13)) { $mes->entities('NameServer',$_.'=') } }
 
  ## $statadd/$statdel are Net::DRI::Protocol::RRP::Core::Status objects
  if (defined($statadd)) { foreach ($statadd->list_status()) { $mes->entities('Status',$_)     } }
  if (defined($statdel)) { foreach ($statdel->list_status()) { $mes->entities('Status',$_.'=') } }
- return;
 }
 
 sub renew
 {
- my ($rrp,$domain,$rd)=@_;
- my ($period,$curexp);
- if (defined($rd) && (ref($rd) eq 'HASH') && keys(%$rd))
- {
-  $period=$rd->{duration};
-  $curexp=$rd->{current_expiration};
- }
+ my ($rrp,$domain,$period,$curexp)=@_;
  Net::DRI::Exceptions::usererr_insufficient_parameters("current expiration year and period must be both defined or not at all") if (defined($curexp) xor defined($period)); ## both or none should be defined
  if (defined($curexp))
  {
@@ -260,8 +238,7 @@ sub renew
  my $mes=$rrp->message();
  build_msg($mes,'renew',$domain);
  $mes->options({Period=>$period,CurrentExpirationYear=>$curexp}) if (defined($period) && defined($curexp));
- return;
 }
 
-####################################################################################################
+#########################################################################################################
 1;
