@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Host commands
 ##
-## Copyright (c) 2005,2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,24 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::RRP::Core::Host;
 
 use strict;
-use warnings;
-
 use Net::DRI::Protocol::RRP;
 use Net::DRI::Data::Hosts;
-use Net::DRI::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::RRP::Core::Host - RRP Host commands for Net::DRI
+Net::DRI::Protocol::RRP::Core::Host
 
 =head1 DESCRIPTION
 
@@ -49,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,6 +63,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
+
 #########################################################################################
 
 sub register_commands
@@ -79,13 +82,12 @@ sub register_commands
 sub build_msg
 {
  my ($msg,$command,$hostname)=@_;
- ($hostname)=$hostname->get_names(1) if (defined($hostname) && ref($hostname));
+ $hostname=$hostname->get_names(1) if (defined($hostname) && ref($hostname));
  Net::DRI::Exception->die(1,'protocol/RRP',3,"Host name needed") unless defined($hostname) && $hostname;
- Net::DRI::Exception->die(1,'protocol/RRP',10,"Invalid host name") unless ($hostname=~m/^([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)*[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?$/i); ## from RRP grammar
+ Net::DRI::Exception->die(1,'protocol/RRP',10,"Invalid host name") unless ($hostname=~m/^([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)?[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.[a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?$/i); ## from RRP grammar
  $msg->command($command) if defined($command);
- $msg->entities('EntityName','NameServer');
- $msg->entities('NameServer',uc $hostname);
- return;
+ $msg->entityname('NameServer');
+ $msg->entities('NameServer',uc($hostname));
 }
 
 sub add
@@ -94,7 +96,6 @@ sub add
  my $mes=$rrp->message();
  build_msg($mes,'add',$ns);
  add_ip($mes,$ns,$rrp->version());
- return;
 }
 
 sub _basic_command
@@ -102,12 +103,11 @@ sub _basic_command
  my ($command,$rrp,$ns)=@_;
  my $mes=$rrp->message();
  build_msg($mes,$command,$ns);
- return;
 }
 
-sub check  { my (@args)=@_; return _basic_command('check',@args);  }
-sub status { my (@args)=@_; return _basic_command('status',@args); }
-sub del    { my (@args)=@_; return _basic_command('del',@args);    }
+sub check  { return _basic_command('check',@_);   }
+sub status { return _basic_command('status',@_);  }
+sub del    { return _basic_command('del',@_);     }
 
 sub check_parse
 {
@@ -115,7 +115,6 @@ sub check_parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- $rinfo->{host}->{$oname}->{action}='check';
  if ($mes->errcode() == 213) ## nameserver exists
  {
   my @ip=$mes->entities('ipaddress');
@@ -125,7 +124,6 @@ sub check_parse
  {
   $rinfo->{host}->{$oname}->{exist}=0;
  }
- return;
 }
 
 sub status_parse
@@ -135,7 +133,6 @@ sub status_parse
  return unless $mes->is_success(); ## if operation succeeds, information should be there
 
  $rinfo->{host}->{$oname}->{exist}=1;
- $rinfo->{host}->{$oname}->{action}='info';
  while(my ($k,$v)=each(%Net::DRI::Protocol::RRP::DATES))
  {
   my $d=$mes->entities($k);
@@ -152,7 +149,6 @@ sub status_parse
 
  my @ip=$mes->entities('ipaddress');
  $rinfo->{host}->{$oname}->{self}=Net::DRI::Data::Hosts->new($oname,\@ip);
- return;
 }
 
 sub mod
@@ -160,7 +156,7 @@ sub mod
  my ($rrp,$hostname,$todo)=@_;
  my $mes=$rrp->message();
 
- Net::DRI::Exception::usererr_invalid_parameters($todo.' must be a Net::DRI::Data::Changes object') unless Net::DRI::Util::isa_changes($todo);
+ Net::DRI::Exception::usererr_invalid_parameters($todo." must be a Net::DRI::Data::Changes object") unless ($todo && ref($todo) && $todo->isa('Net::DRI::Data::Changes'));
  if ((grep { ! /^(?:ip|name)$/ } $todo->types()) ||
      (grep { ! /^(?:add|del)$/ } $todo->types('ip')) ||
      (grep { ! /^(?:set)$/ } $todo->types('name'))
@@ -184,7 +180,6 @@ sub mod
  add_ip($mes,$nsadd,$version);
  add_ip($mes,$nsdel,$version,'=');
  $mes->entities('NewNameServer',ref($newname)? $newname->get_names(1) : $newname) if (defined($newname) && $newname);
- return;
 }
 
 sub add_ip
@@ -197,7 +192,6 @@ sub add_ip
  foreach my $ip (@$r4) { last if $c++>13; $mes->entities('IPAddress',$_.$extra); };
  $c=1;
  if ($version eq '2.0') { foreach my $ip (@$r6) { last if $c++>13; $mes->entities('IPAddress',$_.$extra); } }
- return;
 }
 
 #########################################################################################
