@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRP Session commands
 ##
-## Copyright (c) 2005,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,20 +10,23 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::RRP::Core::Session;
 
 use strict;
-use warnings;
-
 use Net::DRI::Exception;
 
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::RRP::Core::Session - RRP Session commands for Net::DRI
+Net::DRI::Protocol::RRP::Core::Session
 
 =head1 DESCRIPTION
 
@@ -47,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -80,7 +83,6 @@ sub describe
  my $mes=$rrp->message();
  $mes->command('describe');
  $mes->options('Target',$what) if $what;
- return;
 }
 
 sub describe_parse
@@ -90,7 +92,6 @@ sub describe_parse
  return unless $mes->is_success();
 
  $rinfo->{session}->{describe}->{protocol}=$mes->entities('protocol');
- return;
 }
 
 sub quit
@@ -98,7 +99,6 @@ sub quit
  my ($rrp)=@_;
  my $mes=$rrp->message();
  $mes->command('quit');
- return;
 }
 
 sub session
@@ -111,7 +111,6 @@ sub session
  $mes->options('Id',$id);
  $mes->options('Password',$pass);
  $mes->options('NewPassword',$newpass) if (defined($newpass) && $newpass && ($newpass ne $pass));
- return;
 }
 
 ###############################################################################################
