@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Dummy transport for tests & debug
 ##
-## Copyright (c) 2005,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,25 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Transport::Dummy;
 
-use strict;
-use warnings;
-
 use base qw(Net::DRI::Transport);
+use strict;
 
 use Net::DRI::Data::Raw;
 
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d"."%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Transport::Dummy - Net::DRI dummy transport for tests & debug
+Net::DRI::Transport::Dummy
 
 =head1 DESCRIPTION
 
@@ -49,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007,2009,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -61,12 +64,15 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-####################################################################################################
-
 sub new
 {
- my ($class,$ctx,$rh)=@_;
- my $self=$class->SUPER::new($ctx,$rh); ## We are now officially a Net::DRI::Transport instance
+ my $proto=shift;
+ my $class=ref($proto) || $proto;
+
+ my $drd=shift;
+ my $rh=shift;
+
+ my $self=$class->SUPER::new($rh); ## We are now officially a Net::DRI::Transport instance
  $self->has_state(0);
  $self->is_sync(1);
  $self->name('dummy');
@@ -75,19 +81,17 @@ sub new
  $self->{f_send}=(exists($rh->{f_send}))? $rh->{f_send} : \&_print;
  $self->{f_recv}=(exists($rh->{f_recv}))? $rh->{f_recv} : \&_got_ok;
 
+ bless($self,$class); ## rebless in my class
  return $self;
 }
 
-sub send ## no critic (Subroutines::ProhibitBuiltinHomonyms)
-{
- my ($self,$ctx,$tosend)=@_;
- return $self->SUPER::send($ctx,$tosend,$self->{f_send},\&handle_error);
-}
+sub is_compatible_with_protocol { return 1; }
 
-sub handle_error
+sub send
 {
- my ($self,$err,$c,$is_timeout,$ok)=@_;
- die($err->as_string());
+ my $self=shift;
+ my $tosend=shift;
+ $self->SUPER::send($tosend,$self->{f_send});
 }
 
 sub _print
@@ -101,17 +105,21 @@ sub _print
 
 sub receive
 {
- my ($self,$ctx,$count)=@_;
- return $self->SUPER::receive($ctx,$self->{f_recv});
+ my $self=shift;
+
+ return $self->SUPER::receive($self->{f_recv});
 }
 
 sub _got_ok
 {
  my ($self,$count)=@_;
+
  my $m="200 OK\r\n.\r\n";
+ 
  print STDOUT "<<<<<<<<<<<<<<<<<< (Net::DRI::Transport::Dummy) (count=$count)\n";
  print STDOUT $m;
  print STDOUT "<<<<<<<<<<<<<<<<<<\n\n";
+
  return Net::DRI::Data::Raw->new_from_string($m);
 }
 
